@@ -27,7 +27,7 @@ LWSymbol *clone ();
 guint getId ();
 virtual gboolean canClone () = 0;
 virtual gchar *getHint () = 0;
-virtual gchar *getName () = 0;
+virtual const gchar *getName () = 0;
 virtual gboolean isCommand ();
 virtual gboolean isValue ();
 static LWSymbol *factory (const gchar *name);
