@@ -30,7 +30,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return new LWValue(args[0]);
 }
 
-gchar *getName ()
+const gchar *getName ()
 {
 	return "(";
 }	
@@ -42,7 +42,7 @@ gchar *getHint ()
 
 guint getPriority ()
 {
-	return 14;
+	return 15;
 }
 
 LWLink getLinkType ()
