@@ -27,7 +27,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return NULL;
 }
 
-gchar *getName ()
+const gchar *getName ()
 {
 	return ")";
 }	
@@ -39,7 +39,7 @@ gchar *getHint ()
 
 guint getPriority ()
 {
-	return 14;
+	return 15;
 }
 
 LWLink getLinkType ()
