@@ -28,7 +28,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return FALSE;
 }	
 
-gchar *getName (void) 
+const gchar *getName (void) 
 {
 	return "create";
 }	
