@@ -32,7 +32,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return new LWValue (n);
 }
 
-gchar *getName ()
+const gchar *getName ()
 {
 	return "getpositionx";
 }	
