@@ -31,7 +31,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return new LWValue (n);
 }
 
-gchar *getName ()
+const gchar *getName ()
 {
 	return "getpositiony";
 }	
