@@ -30,7 +30,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return NULL;
 }	
 
-gchar *getName (void) 
+const gchar *getName (void) 
 {
 	return "go";
 }	
