@@ -27,7 +27,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return new LWValue (r);
 }
 
-gchar *getName ()
+const gchar *getName ()
 {
 	return "mul";
 }	
