@@ -32,7 +32,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return new LWValue(randv);
 }	
 
-gchar *getName (void) 
+const gchar *getName (void) 
 {
 	return "rand";
 }	
@@ -44,7 +44,12 @@ gchar *getHint ()
 
 guint getPriority ()
 {
-	return 13;
+	return 15;
+}
+
+LWLink getLinkType ()
+{
+	return LW_LINK_RIGHT;
 }
 
 gboolean hasReturn()
