@@ -23,7 +23,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	return NULL;
 }
 
-gchar *getName ()
+const gchar *getName ()
 {
 	return "repeat";
 }	
