@@ -18,7 +18,7 @@
 
 class LWVariableGeneric: public LWVariable, public LWSymbol {
 
-gchar *getName ()
+const gchar *getName ()
 {
 	return "variable";
 }	
