@@ -16,7 +16,7 @@
 #include "include/board.h"
 
 static GtkTargetEntry target_table[] = {
-  { "application/lwizard", GTK_TARGET_SAME_APP, 0 }
+  { (gchar *) "application/lwizard", GTK_TARGET_SAME_APP, 0 }
 };
 
 static guint n_targets = sizeof(target_table) / sizeof(target_table[0]);
