@@ -111,7 +111,7 @@ static void compare_parity (gboolean **r,
 
 static gboolean compare_priority (LWPiece *a, LWPiece *b) 
 {
-
+	const guint maxprio = 16;
 //	if (b == NULL) return TRUE;
 	
 	LWSymbol *sym_a = a->getSymbol();
@@ -120,8 +120,8 @@ static gboolean compare_priority (LWPiece *a, LWPiece *b)
 	LWCommand *cmd_a = NULL;
 	LWCommand *cmd_b = NULL;
 	
-	guint prio_a = 16;
-	guint prio_b = 16;
+	guint prio_a = maxprio;
+	guint prio_b = maxprio;
 	
 	LWLink link = LW_LINK_RIGHT;
 	
@@ -129,13 +129,14 @@ static gboolean compare_priority (LWPiece *a, LWPiece *b)
 		if (TRUE == sym_a->isCommand()) {
 			cmd_a = (LWCommand *) sym_a;
 			prio_a = cmd_a->getPriority();
-			link = cmd_a->getLinkType();
+//			link = cmd_a->getLinkType();
 		}
 
 	if (sym_b != NULL)
 		if (TRUE == sym_b->isCommand()) {
 			cmd_b = (LWCommand *) sym_b;
 			prio_b = cmd_b->getPriority();
+			link = cmd_b->getLinkType();
 		}
 
 	gboolean bo;
@@ -163,7 +164,7 @@ static gboolean compare_priority (LWPiece *a, LWPiece *b)
 	\param piece Klocek z symbolem do zmiany
 	\param symbolname Nazwa symbolu, który ma być skojarzony z klockiem 
 */
-static void toggle_to_symbol (LWPiece *piece, gchar *symbolname) 
+static void toggle_to_symbol (LWPiece *piece, const gchar *symbolname) 
 {
 	if (strcmp(piece->getSymbol()->getName(), symbolname)) {
 		piece->setSymbol (symbolname);
@@ -198,7 +199,8 @@ static void lex_scan (LWPiece *prev, LWPiece *piece)
 		
 		if (TRUE == psymbol->isCommand())
 			if (TRUE == ((LWCommand *) psymbol)->isParity())
-				if (FALSE == ((LWParityCommand *) psymbol)->isOpen()) {
+				if (FALSE == ((LWParityCommand *) psymbol)->isOpen() &&
+					strcmp (psymbol->getName(), "to") && strcmp (psymbol->getName(), "downto")) {
 					toggle_to_symbol (piece, "sub");
 					return;
 				}
